/**
  *  \file client/dialogbinding.h
  *  \brief Script Binding for Dialogs
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_DIALOGBINDING_H
#define PCC_V2_CLIENT_DIALOGBINDING_H

#include "cpluslib/ptrmultilist.h"
#include "int/if/userif.h"
#include "int/keymap.h"

class UIBaseWidget;

/** Script Binding for Dialogs.
    Dialogs that use script bindings can use this class as a second base class.

    Script side behaviour:
    - most commands are given directly to the caller, as well as all property accesses

    C++ side behaviour:
    - the dialog terminates when either a iucExitDialog is posted,
      or stop() is called with a nonzero argument.
    - the binding becomes active when the class is constructed

    Commands are processed in processEvent() which is called outside the script context.
    You can override this to intercept specific commands. */
class IntUserInterfaceDialogBinding : public IntUserInterfaceChildBinding {
 public:
    IntUserInterfaceDialogBinding();
    ~IntUserInterfaceDialogBinding();

    // Main entry:
    int runDialog();
    int runModal(UIBaseWidget& w);

    bool checkKeymap(uint32_t key, int arg);
    void triggerScripts();

    // User callout to process events:
    virtual bool processEvent(std::auto_ptr<IntUserInterfaceEvent> event);
    virtual bool processPreIdle();

    // Implementation of IntUserInterfaceChildBinding methods:
    virtual IntValue* getProperty(IntUserInterfaceProperty p);
    virtual void setProperty(IntUserInterfaceProperty p, IntValue* v);
    virtual void postEvent(std::auto_ptr<IntUserInterfaceEvent> event);
    virtual void enumContexts(ptr_vector<IntContext>& ctx);

 private:
    ptr_multi_list<IntUserInterfaceEvent> eventQueue;
    bool inLoop;

    IntKeymapRef keymap;
    int keymap_prefix;
};

#endif
