/**
  *  \file client/tiles/planettaskcmd.cc
  *  \brief WPlanetAutoTaskCommandTile tile
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planettaskcmd.h"
#include "client/screens/planettaskscreen.h"
#include "game/planet.h"
#include "int/args.h"
#include "int/if/basepred.h"
#include "int/if/ifutil.h"
#include "int/predict.h"
#include "ui/listbox.h"
#include "ui/uiglobal.h"
#include "ui/util.h"
#include "util/nls.h"
#include "util/strlist.h"

static const char*const buttons[] = {
    N_("1 - Orders"),
    N_("2 - Cargo"),
    N_("3 - Misc."),
};

/************************ WBaseAutoTaskCommandTile ***********************/

WPlanetAutoTaskCommandTile::WPlanetAutoTaskCommandTile(GObjectSelection& selection)
    : WTile(GfxPoint(315, 7*font_heights[FONT_NORMAL])),
      atsel(dynamic_cast<WPlanetAutoTaskSelection*>(&selection))
{
    init();
}

WPlanetAutoTaskCommandTile::~WPlanetAutoTaskCommandTile()
{ }

void
WPlanetAutoTaskCommandTile::init()
{
    // Observer
    if (atsel) {
        conn_task_changed =
            atsel->sig_task_changed.add(static_cast<UIBaseWidget*>(this),
                                         (void (UIBaseWidget::*)()) &UIBaseWidget::drawWidget);
    }

    // Controls
    setLayout(RightJustified, 0, true);
    StaticTranslatedStringTable tab(buttons, countof(buttons));
    const int buttonWidth = getTextWidth(*fonts[FONT_SMALL], tab) + 20;
    const int height = font_heights[FONT_SMALL] * 3/2;
    for (uint_t i = 0; i < countof(buttons); ++i) {
        UIButton& btn = h.add(new UIButton(1000+i, tab.get(i), '1'+i));
        btn.addCommand();
        btn.setState(UIButton::bf_LeftJust + UIButton::bf_SmallSize, true);
        addControl(GfxRect(0, (height+2)*i, buttonWidth, height), btn);
    }
}

void
WPlanetAutoTaskCommandTile::drawData(GfxCanvas& /*can*/)
{ }

bool
WPlanetAutoTaskCommandTile::handleCommand(const UICommand& cmd, UIBaseWidget& sender)
{
    switch (cmd.code) {
     case 1000:
        if (atsel != 0) {
            StringList sl;
            sl.add(1, _("Set FCode"));
            UIStandardListbox list(0, sl.getCount(), getTextWidth(*fonts[FONT_NORMAL], sl) + 20, sl);
            if (list.doStandardMenu(sender)) {
                switch (list.getKey()) {
                 case 1:
                    atsel->createSetFCodeCommand();
                    break;
                }
            }
        }
        return true;
     case 1001:
        if (atsel != 0) {
            atsel->createCargoCommand(sender);
        }
        return true;
     case 1002:
        if (atsel != 0) {
            atsel->createCommonCommand(sender, false);
        }
        return true;
    }
    return WTile::handleCommand(cmd, sender);
}
