/**
  *  \file client/widgets/propertylist.cc
  *  \brief WPropertyList widget
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <algorithm>
#include "client/widgets/propertylist.h"
#include "ui/uiglobal.h"
#include "int/names.h"
#include "int/data.h"
#include "int/value.h"
#include "int/propenum.h"
#include "util/nls.h"

/** Constructor.
    \param id Widget Id
    \param names Property names
    \param data Property values */
WPropertyList::WPropertyList(int id,
                             const IntVariableNames& names,
                             const IntDataSegment& data)
    : UIListbox(id, std::min(20, std::max(5, int(names.getNumNames()))), 40 * font_ems[FONT_NORMAL], names.getNumNames()),
      names(names),
      data(data)
{ }

WPropertyList::~WPropertyList()
{ }

void
WPropertyList::drawPart(GfxCanvas& can, int from, int to)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useFont(*fonts[FONT_NORMAL]);

    for (int i = from; i < to; ++i) {
        GfxRect area;
        prepareEntry(ctx, ColorStyle, i, &area);

        int slot = getTop() + i;
        if (slot < names.getNumNames()) {
            area.consumeX(5);
            ctx.setColor(UIColor::tc_Static);
            outTextF(ctx, area.splitX(15 * font_ems[FONT_NORMAL]), beautifyName(names.lookupAddress(slot)));

            if (IntValue* v = data[slot]) {
                outTextF(ctx, area, v->toString(true));
            } else {
                ctx.setColor(UIColor::tc_Faded);
                outTextF(ctx, area, "Empty");
            }
        }
    }
}
