/**
  *  \file ui/widgets/keytranslator.h
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_KEYTRANSLATOR_H
#define PCC_V2_UI_WIDGETS_KEYTRANSLATOR_H

#include <vector>
#include "ui/event.h"
#include "ui/ui.h"

/**
  *  \class UIKeyTranslator
  *  \brief Key to Command Translation
  *
  *  This class provides a means of translating keystrokes into commands.
  *  This widget is invisible.
  *
  *  All action happens in event processing phase 2, so we don't steal
  *  alphanumeric input from widgets that need it more than we.
  */
class UIKeyTranslator : public UIFixedWidget {
 public:
    struct Item {
        UIKey key;
        int   command;
        bool  is_stop;
    };

    UIKeyTranslator();
    UIKeyTranslator(const Item keys[], unsigned n);

    bool handleEvent(const UIEvent& event, bool second_pass);
    void drawContent(GfxCanvas& can);

    UIKeyTranslator& add(const Item keys[], unsigned n);
    UIKeyTranslator& add(UIKey key, int command, bool is_stop);
    UIKeyTranslator& addCommand(UIKey key, int command);
    UIKeyTranslator& addStop(UIKey key, int code);

 private:
    Item* find(UIKey k);
    std::vector<Item> keys;
};


inline UIKeyTranslator&
UIKeyTranslator::addCommand(UIKey key, int command)
{
    return add(key, command, false);
}

inline UIKeyTranslator&
UIKeyTranslator::addStop(UIKey key, int code)
{
    return add(key, code, true);
}

#endif
